# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomermanagedkeyCustomerManagedKeyConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_provider': 'CustomermanagedkeyKeyProvider',
        'kms_key_arn': 'str'
    }

    attribute_map = {
        'key_provider': 'keyProvider',
        'kms_key_arn': 'kmsKeyArn'
    }

    def __init__(self, key_provider=None, kms_key_arn=None):  # noqa: E501
        """CustomermanagedkeyCustomerManagedKeyConfig - a model defined in Swagger"""  # noqa: E501
        self._key_provider = None
        self._kms_key_arn = None
        self.discriminator = None
        if key_provider is not None:
            self.key_provider = key_provider
        self.kms_key_arn = kms_key_arn

    @property
    def key_provider(self):
        """Gets the key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501


        :return: The key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :rtype: CustomermanagedkeyKeyProvider
        """
        return self._key_provider

    @key_provider.setter
    def key_provider(self, key_provider):
        """Sets the key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.


        :param key_provider: The key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :type: CustomermanagedkeyKeyProvider
        """

        self._key_provider = key_provider

    @property
    def kms_key_arn(self):
        """Gets the kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501

        The ARN of the AWS KMS key to use as the customer managed key.  # noqa: E501

        :return: The kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :rtype: str
        """
        return self._kms_key_arn

    @kms_key_arn.setter
    def kms_key_arn(self, kms_key_arn):
        """Sets the kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.

        The ARN of the AWS KMS key to use as the customer managed key.  # noqa: E501

        :param kms_key_arn: The kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :type: str
        """
        if kms_key_arn is None:
            raise ValueError("Invalid value for `kms_key_arn`, must not be `None`")  # noqa: E501

        self._kms_key_arn = kms_key_arn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomermanagedkeyCustomerManagedKeyConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomermanagedkeyCustomerManagedKeyConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
