# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeGetValidateModelTaskStatusResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resp': 'ValidationValidateModelResponse',
        'job_metadata': 'RimeJobMetadata'
    }

    attribute_map = {
        'resp': 'resp',
        'job_metadata': 'jobMetadata'
    }

    def __init__(self, resp=None, job_metadata=None):  # noqa: E501
        """RimeGetValidateModelTaskStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._resp = None
        self._job_metadata = None
        self.discriminator = None
        if resp is not None:
            self.resp = resp
        if job_metadata is not None:
            self.job_metadata = job_metadata

    @property
    def resp(self):
        """Gets the resp of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501


        :return: The resp of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :rtype: ValidationValidateModelResponse
        """
        return self._resp

    @resp.setter
    def resp(self, resp):
        """Sets the resp of this RimeGetValidateModelTaskStatusResponse.


        :param resp: The resp of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :type: ValidationValidateModelResponse
        """

        self._resp = resp

    @property
    def job_metadata(self):
        """Gets the job_metadata of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501


        :return: The job_metadata of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :rtype: RimeJobMetadata
        """
        return self._job_metadata

    @job_metadata.setter
    def job_metadata(self, job_metadata):
        """Sets the job_metadata of this RimeGetValidateModelTaskStatusResponse.


        :param job_metadata: The job_metadata of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :type: RimeJobMetadata
        """

        self._job_metadata = job_metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeGetValidateModelTaskStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeGetValidateModelTaskStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
